==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/ar-SA/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'تاكيد إجراء حذف للاُصول المحددة',
    'bulk_restore'      => 'تأكيد استعادة الأصول بالجملة', 
  'bulk_delete_help'	=> 'الرجاء مراجعة الأصول المحددة للحذف أدناه. بمجرد الحذف، يمكن استعادة هذه الأصول، لكنها لن تكون مرتبطة مع أي من المستخدمين اللذين تم اخراج الأصول لهم من قبل.',
  'bulk_restore_help'	=> 'مراجعة الأصول للاستعادة بالجملة أدناه. بمجرد إعادتها لن تكون هذه الأصول مرتبطة بأي مستعملين سبق تعيينهم.',
  'bulk_delete_warn'	=> 'أنت على وشك حذف :asset_count من الأصول.',
  'bulk_restore_warn'	=> 'أنت على وشك استعادة :asset_count الأصول.',
    'bulk_update'		=> 'تحديث للأصول المحددة',
    'bulk_update_help'	=> 'يتيح لك هذا النموذج تحديث عدة أصول دفعة واحدة. قم بملء الحقول التي تحتاج إلى تغييرها. ستظل أية حقول فارغة بدون تغيير. ',
    'bulk_update_warn'	=> 'أنت على وشك تعديل خصائص أصل واحد.<unk> أنت على وشك تعديل خصائص :asset_count الأصول.',
    'bulk_update_with_custom_field' => 'لاحظ أن الأصول هي :asset_model_count أنواع مختلفة من النماذج.',
    'bulk_update_model_prefix' => 'على النماذج', 
    'bulk_update_custom_field_unique' => 'هذا حقل فريد ولا يمكن تحريره بشكل عام.',
    'checkedout_to'		=> 'تم الاخراج إلى',
    'checkout_date'		=> 'تاريخ الاخراج',
    'checkin_date'		=> 'تاريخ الادخال',
    'checkout_to'		=> 'اخراج إلى',
    'cost'				=> 'تكلفة الشراء',
    'create'			=> 'إنشاء أصل',
    'date'				=> 'تاريخ الشراء',
    'depreciation'	    => 'الاستهلاك',
    'depreciates_on'	=> 'ينتهي الاستهلاك في',
    'default_location'	=> 'الموقع الافتراضي',
    'default_location_phone' => 'هاتف الموقع الافتراضي',
    'eol_date'			=> 'تاريخ نهاية العمر',
    'eol_rate'			=> 'معدل انتهاء العمر',
    'expected_checkin'  => 'تاريخ الادخال المتوقع',
    'expires'			=> 'انتهاء الصلاحية',
    'fully_depreciated'	=> 'مستهلك بالكامل',
    'help_checkout'		=> 'إذا كنت ترغب في اخراج هذا الأصل فورا، فحدد "جاهز للتوزيع" من قائمة الحالة أعلاه. ',
    'mac_address'		=> 'عنوان ماك (MAC)',
    'manufacturer'		=> 'الصانع',
    'model'				=> 'الموديل',
    'months'			=> 'أشهر',
    'name'				=> 'اسم الأصل',
    'notes'				=> 'مُلاحظات',
    'order'				=> 'رقم طلب الشراء',
    'qr'				=> 'رمز الاستجابة السريعة QR',
    'requestable'		=> 'يمكن للمستخدمين طلب هذا الأصل',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'حدد نوع الحالة',
    'serial'			=> 'التسلسل',
    'status'			=> 'الحالة',
    'tag'				=> 'ترميز الأصل',
    'update'			=> 'تحديث الأصل',
    'warranty'			=> 'الضمان',
        'warranty_expires'		=> 'انتهاء مدة صلاحية الضمان',
    'years'				=> 'سنوات',
    'asset_location' => 'تحديث موقع الأصل',
    'asset_location_update_default_current' => 'تحديث الموقع الافتراضي والموقع الفعلي',
    'asset_location_update_default' => 'تحديث الموقع الافتراضي فقط',
    'asset_location_update_actual' => 'تحديث الموقع الفعلي فقط',
    'asset_not_deployable' => 'حالة الأصول هذه غير قابلة للنشر. لا يمكن التحقق من هذه الأصول.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'حالة تلك الأصول قابلة للنشر. هذا الأصل يمكن إخراجه.',
    'processing_spinner' => 'معالجة... (قد يستغرق هذا بعض الوقت على ملفات كبيرة)',
    'optional_infos'  => 'معلومات اختيارية',
    'order_details'   => 'معلومات ذات صلة',
    'calc_eol'    => 'If nulling the EOL date, use automatic EOL calculation based on the purchase date and EOL rate.',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/ar-SA/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'تاكيد إجراء حذف للاُصول المحددة',
    'bulk_restore'      => 'تأكيد استعادة الأصول بالجملة', 
  'bulk_delete_help'	=> 'الرجاء مراجعة الأصول المحددة للحذف أدناه. بمجرد الحذف، يمكن استعادة هذه الأصول، لكنها لن تكون مرتبطة مع أي من المستخدمين اللذين تم اخراج الأصول لهم من قبل.',
  'bulk_restore_help'	=> 'مراجعة الأصول للاستعادة بالجملة أدناه. بمجرد إعادتها لن تكون هذه الأصول مرتبطة بأي مستعملين سبق تعيينهم.',
  'bulk_delete_warn'	=> 'أنت على وشك حذف :asset_count من الأصول.',
  'bulk_restore_warn'	=> 'أنت على وشك استعادة :asset_count الأصول.',
    'bulk_update'		=> 'تحديث للأصول المحددة',
    'bulk_update_help'	=> 'يتيح لك هذا النموذج تحديث عدة أصول دفعة واحدة. قم بملء الحقول التي تحتاج إلى تغييرها. ستظل أية حقول فارغة بدون تغيير. ',
    'bulk_update_warn'	=> 'أنت على وشك تعديل خصائص أصل واحد.<unk> أنت على وشك تعديل خصائص :asset_count الأصول.',
    'bulk_update_with_custom_field' => 'لاحظ أن الأصول هي :asset_model_count أنواع مختلفة من النماذج.',
    'bulk_update_model_prefix' => 'على النماذج', 
    'bulk_update_custom_field_unique' => 'هذا حقل فريد ولا يمكن تحريره بشكل عام.',
    'checkedout_to'		=> 'تم الاخراج إلى',
    'checkout_date'		=> 'تاريخ الاخراج',
    'checkin_date'		=> 'تاريخ الادخال',
    'checkout_to'		=> 'اخراج إلى',
    'cost'				=> 'تكلفة الشراء',
    'create'			=> 'إنشاء أصل',
    'date'				=> 'تاريخ الشراء',
    'depreciation'	    => 'الاستهلاك',
    'depreciates_on'	=> 'ينتهي الاستهلاك في',
    'default_location'	=> 'الموقع الافتراضي',
    'default_location_phone' => 'هاتف الموقع الافتراضي',
    'eol_date'			=> 'تاريخ نهاية العمر',
    'eol_rate'			=> 'معدل انتهاء العمر',
    'expected_checkin'  => 'تاريخ الادخال المتوقع',
    'expires'			=> 'انتهاء الصلاحية',
    'fully_depreciated'	=> 'مستهلك بالكامل',
    'help_checkout'		=> 'إذا كنت ترغب في اخراج هذا الأصل فورا، فحدد "جاهز للتوزيع" من قائمة الحالة أعلاه. ',
    'mac_address'		=> 'عنوان ماك (MAC)',
    'manufacturer'		=> 'الصانع',
    'model'				=> 'الموديل',
    'months'			=> 'أشهر',
    'name'				=> 'اسم الأصل',
    'notes'				=> 'مُلاحظات',
    'order'				=> 'رقم طلب الشراء',
    'qr'				=> 'رمز الاستجابة السريعة QR',
    'requestable'		=> 'يمكن للمستخدمين طلب هذا الأصل',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'حدد نوع الحالة',
    'serial'			=> 'التسلسل',
    'serial_required'	=> 'Asset :number requires a serial number',
    'serial_required_post_model_update'	=> ':asset_model have been updated to require a serial number. Please add a serial number for this asset.',
    'status'			=> 'الحالة',
    'tag'				=> 'ترميز الأصل',
    'update'			=> 'تحديث الأصل',
    'warranty'			=> 'الضمان',
        'warranty_expires'		=> 'انتهاء مدة صلاحية الضمان',
    'years'				=> 'سنوات',
    'asset_location' => 'تحديث موقع الأصل',
    'asset_location_update_default_current' => 'تحديث الموقع الافتراضي والموقع الفعلي',
    'asset_location_update_default' => 'تحديث الموقع الافتراضي فقط',
    'asset_location_update_actual' => 'تحديث الموقع الفعلي فقط',
    'asset_not_deployable' => 'حالة الأصول هذه غير قابلة للنشر. لا يمكن التحقق من هذه الأصول.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'This asset can be checked out.',
    'processing_spinner' => 'معالجة... (قد يستغرق هذا بعض الوقت على ملفات كبيرة)',
    'processing' => 'Processing... ',
    'optional_infos'  => 'معلومات اختيارية',
    'order_details'   => 'معلومات ذات صلة',
    'calc_eol'    => 'If nulling the EOL date, use automatic EOL calculation based on the purchase date and EOL rate.',
];
